CATEGORY_MAPPING = {
    "Data": [
        "Data Science",
        "Data Scientist",
        "Machine Learning Engineer",
        "AI",
        "Hadoop",
    ],
    "Development - Backend": [
        "Backend Developer",
        "Python Developer",
        "Java Developer",
        "DotNet Developer",
        "Full Stack Developer",
    ],
    "Development - Frontend": ["Frontend Developer", "Web Designing"],
    "Mobile Development": ["Mobile App Developer (iOS/Android)"],
    "DevOps & Cloud": ["DevOps Engineer", "Cloud Engineer"],
    "Testing": ["Testing", "Automation Testing", "ETL Developer"],
    "Engineering": ["Mechanical Engineer", "Civil Engineer", "Electrical Engineering"],
    "Security": ["Network Security Engineer"],
    "Business": ["Business Analyst", "PMO", "Operations Manager", "Sales"],
    "HR": ["HR"],
    "Design": ["Arts", "Health and fitness"],
    "Blockchain": ["Blockchain"],
    "SAP": ["SAP Developer"],
    "Database": ["Database"],
    "Legal": ["Advocate"],
}
